@@ -30,8 +30,12 @@ class AudioPlayerViewController: PlayerViewController {
         get { return UIInterfaceOrientationMask.portrait }
     }
 
+    override var preferredStatusBarStyle: UIStatusBarStyle {
+        return .lightContent
+    }
+
     lazy var audioPlayerView: AudioPlayerView = {
-        let audioPlayerView: AudioPlayerView = Bundle.main.loadNibNamed("AudioPlayerView", owner: nil)?.first as! AudioPlayerView
+        let audioPlayerView = AudioPlayerView(frame: .zero)
         audioPlayerView.delegate = self
         return audioPlayerView
     }()
@@ -60,12 +64,12 @@ class AudioPlayerViewController: PlayerViewController {
         self.playerController.delegate = self
         mediaNavigationBar.addMoreOptionsButton(moreOptionsButton)
         audioPlayerView.setupNavigationBar(with: mediaNavigationBar)
-        audioPlayerView.setupThumbnailView()
+        audioPlayerView.updateThumbnailImageView()
         audioPlayerView.setupBackgroundColor()
-        audioPlayerView.setupPlayerControls()
         mediaScrubProgressBar.updateBackgroundAlpha(with: 0.0)
         audioPlayerView.setupProgressView(with: mediaScrubProgressBar)
         audioPlayerView.setupExternalOutputView(with: externalOutputView)
+        audioPlayerView.setupSliders()
         setupAudioPlayerViewConstraints()
         setupOptionsNavigationBar()
         setupStatusLabel()
@@ -82,9 +86,10 @@ class AudioPlayerViewController: PlayerViewController {
         playbackService.recoverPlaybackState()
         seekForwardBy = UserDefaults.standard.integer(forKey: kVLCSettingPlaybackForwardSkipLength)
         seekBackwardBy = UserDefaults.standard.integer(forKey: kVLCSettingPlaybackBackwardSkipLength)
-        audioPlayerView.setupThumbnailView()
+        audioPlayerView.updateThumbnailImageView()
         audioPlayerView.setupBackgroundColor()
         setupGestures()
+        playModeUpdated()
 
         if playbackService.isPlayingOnExternalScreen() {
             changeOutputView(to: externalOutputView.displayView)
@@ -94,6 +99,8 @@ class AudioPlayerViewController: PlayerViewController {
     override func viewWillDisappear(_ animated: Bool) {
         playerController.isInterfaceLocked = false
         queueViewController?.hide()
+        numberOfTapSeek = 0
+        previousSeekState = .default
     }
 
     // MARK: Public methods
@@ -142,6 +149,7 @@ class AudioPlayerViewController: PlayerViewController {
         audioPlayerView.thumbnailView.addGestureRecognizer(panRecognizer)
         audioPlayerView.thumbnailView.addGestureRecognizer(leftSwipeRecognizer)
         audioPlayerView.thumbnailView.addGestureRecognizer(rightSwipeRecognizer)
+        audioPlayerView.thumbnailView.addGestureRecognizer(doubleTapGestureRecognizer)
         audioPlayerView.addGestureRecognizer(playPauseRecognizer)
         audioPlayerView.addGestureRecognizer(pinchRecognizer)
 
@@ -167,6 +175,22 @@ class AudioPlayerViewController: PlayerViewController {
         audioPlayerView.thumbnailView.isHidden = true
     }
 
+    override func handleDoubleTapGesture(_ sender: UITapGestureRecognizer) {
+        let screenWidth: CGFloat = view.frame.size.width
+        let middleBoundary: CGFloat = screenWidth / 2.0
+
+        let tapPosition = sender.location(in: view)
+
+        // Reset number(set to -1/1) of seek when orientation has been changed.
+        if tapPosition.x < middleBoundary {
+            numberOfTapSeek = previousSeekState == .forward ? -1 : numberOfTapSeek - 1
+        } else {
+            numberOfTapSeek = previousSeekState == .backward ? 1 : numberOfTapSeek + 1
+        }
+
+        super.handleDoubleTapGesture(sender)
+    }
+
     // MARK: - Private methods
 
     private func setupAudioPlayerViewConstraints() {
@@ -256,8 +280,8 @@ extension AudioPlayerViewController: AudioPlayerViewDelegate {
         return image
     }
 
-    func audioPlayerViewDelegateDidTapBackwardButton(_ audioPlayerView: AudioPlayerView) {
-        playbackService.jumpBackward(Int32(seekBackwardBy))
+    func audioPlayerViewDelegateDidTapShuffleButton(_ audioPlayerView: AudioPlayerView) {
+        updateShuffleState()
     }
 
     func audioPlayerViewDelegateDidTapPreviousButton(_ audioPlayerView: AudioPlayerView) {
@@ -273,8 +297,8 @@ extension AudioPlayerViewController: AudioPlayerViewDelegate {
         playbackService.next()
     }
 
-    func audioPlayerViewDelegateDidTapForwardButton(_ audioPlayerView: AudioPlayerView) {
-        playbackService.jumpForward(Int32(seekForwardBy))
+    func audioPlayerViewDelegateDidTapRepeatButton(_ audioPlayerView: AudioPlayerView) {
+        updateRepeatMode()
     }
 
     func audioPlayerViewDelegateGetBrightnessSlider(_ audioPlayerView: AudioPlayerView) -> BrightnessControlView {
@@ -291,6 +315,7 @@ extension AudioPlayerViewController: AudioPlayerViewDelegate {
 extension AudioPlayerViewController {
     func prepare(forMediaPlayback playbackService: PlaybackService) {
         audioPlayerView.updatePlayButton(isPlaying: playbackService.isPlaying)
+        audioPlayerView.updateShuffleRepeatState(shuffleEnabled: playbackService.isShuffleMode, repeatMode: playbackService.repeatMode)
 
         let metadata = playbackService.metadata
         audioPlayerView.updateLabels(title: metadata.title, artist: metadata.artist, isQueueHidden: isQueueHidden)
@@ -338,7 +363,7 @@ extension AudioPlayerViewController {
         updateNavigationBar(with: isQueueHidden ? nil : metadata.title)
 
         if metadata.artworkImage != audioPlayerView.thumbnailImageView.image {
-            audioPlayerView.setupThumbnailView()
+            audioPlayerView.updateThumbnailImageView()
             audioPlayerView.setupBackgroundColor()
 
             if let qvc = queueViewController, !isQueueHidden {
@@ -346,6 +371,10 @@ extension AudioPlayerViewController {
             }
         }
     }
+
+    func playModeUpdated() {
+        audioPlayerView.updateShuffleRepeatState(shuffleEnabled: playbackService.isShuffleMode, repeatMode: playbackService.repeatMode)
+    }
 }
 
 // MARK: - PlayerControllerDelegate
