@@ -5,13 +5,14 @@
  *
  * Authors: Soomin Lee <bubu@mikan.io>
  *          Edgar Fouillet <vlc # edgar.fouillet.eu>
+ *          Diogo Simao Marques <dogo@videolabs.io>
  *
  * Refer to the COPYING file of the official project for license.
  *****************************************************************************/
 
 @objc(VLCQueueViewControllerDelegate)
 protocol QueueViewControllerDelegate {
-    func queueViewControllerDidDisappear(_ queueViewController: QueueViewController?)
+    @objc optional func queueViewControllerDidDisappear(_ queueViewController: QueueViewController?)
 }
 
 class QueueViewFlowLayout: UICollectionViewFlowLayout {
@@ -78,6 +79,8 @@ class QueueViewController: UIViewController {
     }
     var bottomConstraint: NSLayoutConstraint?
 
+    var heightConstraint: NSLayoutConstraint?
+
     private var darkOverlayView: UIView = UIView()
     private var darkOverlayViewConstraints: [NSLayoutConstraint] = []
 
@@ -110,7 +113,9 @@ class QueueViewController: UIViewController {
 
     override func viewWillDisappear(_ animated: Bool) {
         super.viewWillDisappear(animated)
-        delegate?.queueViewControllerDidDisappear(self)
+        if let delegate = delegate as? VideoPlayerViewController {
+            delegate.queueViewControllerDidDisappear(self)
+        }
     }
 
     override func viewDidDisappear(_ animated: Bool) {
@@ -133,7 +138,11 @@ class QueueViewController: UIViewController {
                 darkOverlayView.bottomAnchor.constraint(equalTo: parent.view.bottomAnchor)
             ]
 
-            let heightConstraint: NSLayoutConstraint?
+            if let heightConstraint = heightConstraint {
+                view.removeConstraint(heightConstraint)
+            }
+
+            var miniPlayerView: AudioMiniPlayer? = nil
             if let parent = parent as? VLCPlayerDisplayController, let miniPlaybackView = parent.miniPlaybackView as? AudioMiniPlayer {
                 grabberView.isHidden = true
                 closeButton.isHidden = true
@@ -141,6 +150,7 @@ class QueueViewController: UIViewController {
                 topConstraint = view.topAnchor.constraint(equalTo: miniPlaybackView.bottomAnchor)
                 heightConstraint = nil
                 bottomConstraint = view.bottomAnchor.constraint(equalTo: parent.view.bottomAnchor)
+                miniPlayerView = miniPlaybackView
             } else {
                 grabberView.isHidden = false
                 closeButton.isHidden = false
@@ -150,16 +160,42 @@ class QueueViewController: UIViewController {
                                                                     constant: -(topConstraintConstant + parent.videoPlayerControls.frame.height + parent.scrubProgressBar.frame.height))
                     bottomConstraint = view.bottomAnchor.constraint(equalTo: parent.view.bottomAnchor,
                                                                     constant: self.view.frame.height)
+                } else if let parent = parent as? AudioPlayerViewController {
+                    heightConstraint = view.heightAnchor.constraint(equalToConstant: parent.audioPlayerView.playqueueView.bounds.height)
+                    grabberView.isHidden = true
+                    closeButton.isHidden = true
+                    topConstraint = view.topAnchor.constraint(equalTo: parent.audioPlayerView.playqueueView.topAnchor)
+                    bottomConstraint = view.bottomAnchor.constraint(equalTo: parent.audioPlayerView.playqueueView.bottomAnchor)
+                    darkOverlayView.isHidden = true
                 } else {
                     topConstraint = view.topAnchor.constraint(equalTo: parent.view.bottomAnchor)
                     heightConstraint = nil
                     bottomConstraint = view.bottomAnchor.constraint(equalTo: parent.view.bottomAnchor)
                 }
             }
+
             parent.view.addSubview(view)
+
+            let leadingAnchor: NSLayoutXAxisAnchor
+            let trailingAnchor: NSLayoutXAxisAnchor
+            if #available(iOS 11.0, *) {
+                let safeArea: UILayoutGuide
+                if let miniPlayerView = miniPlayerView {
+                    safeArea = miniPlayerView.safeAreaLayoutGuide
+                } else {
+                    safeArea = parent.view.safeAreaLayoutGuide
+                }
+
+                leadingAnchor = safeArea.leadingAnchor
+                trailingAnchor = safeArea.trailingAnchor
+            } else {
+                leadingAnchor = parent.view.leadingAnchor
+                trailingAnchor = parent.view.trailingAnchor
+            }
+
             constraints = [
-                view.leadingAnchor.constraint(equalTo: parent.view.leadingAnchor),
-                view.trailingAnchor.constraint(equalTo: parent.view.trailingAnchor)
+                view.leadingAnchor.constraint(equalTo: leadingAnchor),
+                view.trailingAnchor.constraint(equalTo: trailingAnchor)
             ]
 
             if let topConstraint = topConstraint {
@@ -260,6 +296,15 @@ class QueueViewController: UIViewController {
         })
     }
 
+    func dismissFromAudioPlayer() {
+        UIView.animate(withDuration: animationDuration, animations: {
+            self.view.alpha = 0.0
+        }, completion: { _ in
+            self.view.removeFromSuperview()
+            self.removeFromParent()
+        })
+    }
+
     @objc private func dismissPlayqueue() {
         if let parent = parent {
             var newY: CGFloat = view.frame.height
@@ -410,9 +455,13 @@ private extension QueueViewController {
     }
 
     @objc private func dismissView() {
+        guard let delegate = delegate as? VideoPlayerViewController else {
+            return
+        }
+
         dismiss(animated: true) {
             [weak self] in
-            self?.delegate?.queueViewControllerDidDisappear(self)
+            delegate.queueViewControllerDidDisappear(self)
         }
     }
 }
@@ -423,7 +472,7 @@ extension QueueViewController: UICollectionViewDelegateFlowLayout {
     func collectionView(_ collectionView: UICollectionView,
                         layout collectionViewLayout: UICollectionViewLayout,
                         sizeForItemAt indexPath: IndexPath) -> CGSize {
-        return CGSize(width: collectionView.frame.width - (sidePadding * 2), height: cellHeight)
+        return MediaCollectionViewCell.cellSizeForWidth(collectionView.frame.width - (sidePadding * 2))
     }
 
     func collectionView(_ collectionView: UICollectionView,
@@ -504,6 +553,10 @@ extension QueueViewController: UICollectionViewDelegate, MediaCollectionViewCell
 
         return nil
     }
+
+    func mediaCollectionViewCellGetModel() -> MediaLibraryBaseModel? {
+        return nil
+    }
 }
 
 // MARK: - UIScrollViewDelegate
@@ -581,7 +634,7 @@ extension QueueViewController: UICollectionViewDataSource {
 
         var media: VLCMedia?
 
-        cell.thumbnailWidth.constant = cell.frame.height
+        cell.thumbnailWidth.constant = cell.getDefaultConstant()
 
         cell.ignoreThemeDidChange = true
         cell.setTheme(to: PresentationTheme.darkTheme)
@@ -605,6 +658,7 @@ extension QueueViewController: UICollectionViewDataSource {
             cell.media = media
         }
         cell.newLabel.isHidden = true
+
         return cell
     }
 }
